# -*- coding: utf-8 -*-
"""
Pull pangrams from a variety of world languages for template testing.

A pangram is a phrase that includes every letter of an alphabet.

The list is drawn from the Web site of Markus Kuhn.
http://www.cl.cam.ac.uk/~mgk25/ucs/examples/quickbrown.txt
"""

PANGRAMS = {
'en': 'The quick brown fox jumps over the lazy dog.',
'da': 'Quizdeltagerne spiste jordbær med fløde, mens cirkusklovnen Wolther spillede på xylofon.',
'de': 'Falsches Üben von Xylophonmusik quält jeden größeren Zwerg.',
'el': 'Γαζέες καὶ μυρτιὲς δὲν θὰ βρῶ πιὰ στὸ χρυσαφὶ ξέφωτο.',
'es': 'El pingüino Wenceslao hizo kilómetros bajo exhaustiva lluvia y frío, añoraba a su querido cachorro.',
'fr': "Portez ce vieux whisky au juge blond qui fume sur son île intérieure, à côté de l'alcôve ovoïde, où les bûches se consument dans l'âtre, ce qui lui permet de penser à la cænogenèse de l'être dont il est question dans la cause ambiguë entendue à Moÿ, dans un capharnaüm qui, pense-t-il, diminue çà et là la qualité de son œuvre.",
'ga': "D'fhuascail Íosa, Úrmhac na hÓighe Beannaithe, pór Éava agus Ádhaimh.",
'hu': 'Árvíztűrő tükörfúrógép.',
'is': 'Kæmi ný öxi hér ykist þjófum nú bæði víl og ádrepa.',
'jp': """'いろはにほへとちりぬるを
  わかよたれそつねならむ
  うゐのおくやまけふこえて
  あさきゆめみしゑひもせす""",
'iw': '? דג סקרן שט בים מאוכזב ולפתע מצא לו חברה איך הקליטה.',
'pl': 'Pchnąć w tę łódź jeża lub ośm skrzyń fig.',
'ru': 'чащах юга жил бы цитрус? Да, но фальшивый экземпляр!'
}

def get_pangram(language='en'):
    """
    Returns a pangram in the specified language. The default is English.
    """
    return PANGRAMS[language]
    
def get_html(pangram):
    """
    Renders the provided pangram in HTML by wrapping it in <p> tags.
    
    Linebreaks are replaced with <br> tags.
    """
    html = '<p>%s</p>' % pangram
    html = html.replace("\n", "<br>")
    return html


from django.test import TestCase
from django.template import Template, Context

from greeking.lorem_ipsum import words, paragraphs
from greeking.jabberwocky import get_grafs, get_html as get_jabberwocky_html
from greeking.pangrams import PANGRAMS, get_pangram, get_html as get_pangram_html
from greeking import quotables

from django.utils.encoding import smart_unicode

import datetime

class GreekingTemplateTagTests(TestCase):

	def render(self, t, **c):
		ctx = Context(c)
		out = Template(t).render(ctx)
		return ctx, out

	def testJabberwocky(self):
		"""
		Tests the tag for pulling jabberwocky
		"""
		graph_range = range(1, 8)
		for graphs in graph_range:
			t = "{% load greeking_tags %}{% jabberwocky " + str(graphs) + " %}"
			ctx, out = self.render(t)
			match = get_jabberwocky_html(get_grafs(graphs))
			self.assertEqual(out, match)
		
	def testPangrams(self):
		"""
		Tests the tag for pulling pangrams
		"""
		languages = PANGRAMS.keys()
		for language in languages:
			t = "{% load greeking_tags %}{% pangram " + language + " %}"
			ctx, out = self.render(t)
			match = get_pangram_html(get_pangram(language))
			self.assertEqual(out, smart_unicode(match))

	def testGreekComments(self):
		"""
		Tests the tag for pulling greek comments
		"""
		t = "{% load greeking_tags %}{% greek_comment_list as comment_list %}"
		ctx, out = self.render(t)
		for comment in list(ctx['comment_list']):
			comment_dict = {
				'user_name': comment.user_name,
				'user_email': comment.user_email,
				'user_url': comment.user_url,
				'comment': comment.comment,
				'submit_date': comment.submit_date
			}
			match = quotables.HIPHOP[comment.comment_id]
			for k, v in comment_dict.items():
				self.assertEqual(v, match[k])
		
			
			
			
			
			
			


from setuptools import setup, find_packages

setup(name='greeking',
      version='0.1',
      description='Tools for printing filler text, a technique from the days of hot type known as greeking.',
      author='Ben Welsh',
      author_email='Benjamin.Welsh@latimes.com',
      url='http://github.com/palewire/django-greeking',
      download_url='http://github.com/palewire/django-greeking.git',
      packages=find_packages(),
      license='MIT',
      keywords='greeking pangrams lorem ipsum quotables comments text jabberwocky',
      classifiers=["Intended Audience :: Developers",
                   "Intended Audience :: Science/Research",
                   "License :: OSI Approved :: MIT License",
                   "Operating System :: OS Independent",
                   "Programming Language :: Python",
                   "Topic :: Software Development :: Libraries :: Python Modules"
                   ],
     )
